@@ -35,3 +35,17 @@ def test_command_line_interface():
     help_result = runner.invoke(cli.main, ['--help'])
     assert help_result.exit_code == 0
     assert '--help  Show this message and exit.' in help_result.output
+
+
+def test_ingredients(capsys):
+    """We use the capsys argument to capture printing to stdout."""
+    # The ingredients function prints the results, but returns nothing.
+    assert leeeeon4_test_package.ingredients(10) is None
+
+    # Capture the result of the arepas.ingredients() function call.
+    captured = capsys.readouterr()
+
+    # If we check captured, we can see that the ingredients have been printed.
+    assert "1.0 cups arepa flour" in captured.out
+    assert "1.0 cups cheese" in captured.out
+    assert "0.25 cups water" in captured.out
